@@ -4,11 +4,10 @@
 #include "Rivet/Projections/VetoedFinalState.hh"
 #include "Rivet/Projections/IdentifiedFinalState.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/FastJets.hh"
 #include "Rivet/Projections/PartonicTops.hh"
 #include "Rivet/Math/LorentzTrans.hh"
-#include "Rivet/Tools/BinnedHistogram.hh"
 
 namespace Rivet {
 
@@ -18,7 +17,7 @@ namespace Rivet {
   public:
 
       /// Constructor
-      DEFAULT_RIVET_ANALYSIS_CTOR(ATLAS_2022_I2077575);
+      RIVET_DEFAULT_ANALYSIS_CTOR(ATLAS_2022_I2077575);
 
       /// Book histograms and initialise projections before the run
       void init() {
@@ -30,14 +29,16 @@ namespace Rivet {
 
         // External bins for 2D and 3D cross-sections
         std::vector<double> t1_pt_2D_bins_1 = {0.5, 0.55, 0.6, 0.75, 2.0};
-	      std::vector<double> t1_pt_2D_bins_2 = {0.5, 0.55, 0.625, 0.75, 2.0};
+        std::vector<double> t1_pt_2D_bins_2 = {0.5, 0.55, 0.625, 0.75, 2.0};
         std::vector<double> t_and_tt_y_2D_bins = {0.0, 0.2, 0.5, 1.0, 2.0};
         std::vector<double> tt_pt_2D_bins = {0.0, 0.1, 0.2, 0.35, 1.0};
         std::vector<double> tt_m_3D_bins = {0.9, 1.2, 1.5, 4.0};
 
         //histogram booking
         book(_h["inclusive_particle"], 2, 1, 1);
-        if (_mode)  book(_h["inclusive_parton"], 147, 1, 1);
+        if (_mode) {
+          book(_h["inclusive_parton"], 147, 1, 1);
+        }
         book_hist("t_pt", 	       3);
         book_hist("t_y",  	       4);
         book_hist("t1_pt",         5);
@@ -70,9 +71,9 @@ namespace Rivet {
         book_hist_2D("tt_y_3_tt_m_t1_pt_3D", 	tt_m_3D_bins, 		    72);
 
         // Projections
-        const Cut dressed_lep = (Cuts::abseta < 2.5) && (Cuts::pT >= 25*GeV);
-        const Cut all_dressed_lep = (Cuts::abseta < 2.5);
-        const Cut eta_full = (Cuts::abseta < 4.5);
+        const Cut dressed_lep = Cuts::abseta < 2.5 && Cuts::pT >= 25*GeV;
+        const Cut all_dressed_lep = Cuts::abseta < 2.5;
+        const Cut eta_full = Cuts::abseta < 4.5;
 
         // All final state particles
         const FinalState fs(eta_full);
@@ -81,26 +82,28 @@ namespace Rivet {
         const FinalState photons(Cuts::abspid == PID::PHOTON);
 
         // Projection to find the electrons
-        PromptFinalState electrons(Cuts::abspid == PID::ELECTRON, true);
-        DressedLeptons dressedelectrons(photons, electrons, 0.1, dressed_lep);
+        PromptFinalState electrons(Cuts::abspid == PID::ELECTRON, TauDecaysAs::PROMPT);
+        LeptonFinder dressedelectrons(electrons, photons, 0.1, dressed_lep);
         declare(dressedelectrons, "elecs");
-        DressedLeptons alldressedelectrons(photons, electrons, 0.1, all_dressed_lep, true);
+        LeptonFinder alldressedelectrons(electrons, photons, 0.1, all_dressed_lep);
 
         // Projection to find the muons
-        PromptFinalState muons(Cuts::abspid == PID::MUON, true);
-        DressedLeptons dressedmuons(photons, muons, 0.1, dressed_lep);
+        PromptFinalState muons(Cuts::abspid == PID::MUON, TauDecaysAs::PROMPT);
+        LeptonFinder dressedmuons(muons, photons, 0.1, dressed_lep);
         declare(dressedmuons, "muons");
-        DressedLeptons alldressedmuons(photons, muons, 0.1, all_dressed_lep, true);
+        LeptonFinder alldressedmuons(muons, photons, 0.1, all_dressed_lep);
 
         // Small-R jet clustering
         VetoedFinalState vfs(fs);
         vfs.addVetoOnThisFinalState(alldressedelectrons);
         vfs.addVetoOnThisFinalState(alldressedmuons);
-        FastJets sjets(vfs, FastJets::ANTIKT, 0.4, JetAlg::Muons::ALL, JetAlg::Invisibles::DECAY);
+        FastJets sjets(vfs, JetAlg::ANTIKT, 0.4, JetMuons::ALL, JetInvisibles::DECAY);
         declare(sjets, "sjets");
 
         // Large-R jet clustering.
-        FastJets ljets(fs, FastJets::ANTIKT, 1.0, JetAlg::Muons::NONE, JetAlg::Invisibles::NONE);
+        FastJets ljets(fs, JetAlg::ANTIKT, 1.0, JetMuons::NONE, JetInvisibles::NONE);
+        ljets.addTrf(new fastjet::Filter(fastjet::JetDefinition(fastjet::kt_algorithm, 0.2),
+                                         fastjet::SelectorPtFractionMin(0.05)));
         declare(ljets, "ljets");
 
         if (_mode) {
@@ -194,8 +197,8 @@ namespace Rivet {
         const Jets all_sjets = sjets_fj.jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta < 2.5);
 
         // Get dressed leptons
-        vector<DressedLepton> dressedElectrons = apply<DressedLeptons>(event, "elecs").dressedLeptons();
-        vector<DressedLepton> dressedMuons     = apply<DressedLeptons>(event, "muons").dressedLeptons();
+        DressedLeptons dressedElectrons = apply<LeptonFinder>(event, "elecs").dressedLeptons();
+        DressedLeptons dressedMuons     = apply<LeptonFinder>(event, "muons").dressedLeptons();
 
         // Perform lepton isolation
         idiscardIfAnyDeltaRLess(dressedElectrons, all_sjets, 0.4);
@@ -207,15 +210,7 @@ namespace Rivet {
 
         // Get large-R jets
         const FastJets& ljets_fj = apply<FastJets>(event, "ljets");
-        const Jets all_ljets = ljets_fj.jetsByPt();
-
-        // Trim the large-R jets
-        Jets trimmedJets;
-        fastjet::Filter trimmer(fastjet::JetDefinition(fastjet::kt_algorithm, 0.2), fastjet::SelectorPtFractionMin(0.05));
-        for (const Jet& jet : all_ljets) {
-          trimmedJets += ljets_fj.trimJet(jet, trimmer);
-        }
-        trimmedJets = sortByPt(trimmedJets);
+        const Jets& trimmedJets = ljets_fj.jetsByPt();
 
         // Check large-R jets
         Jets ljets;
@@ -329,7 +324,7 @@ namespace Rivet {
 
       void finalize() {
         // Normalize histograms to cross-section in femtobarns (for consistency with HEPData)
-        const double sf = crossSection() * 1000 / sumOfWeights();
+        const double sf = crossSection()/picobarn * 1000 / sumOfWeights();
         for (auto& h_it : _h) {
           scale(h_it.second, sf);
           // Parton-level distributions corrected for all-hadronic branching fraction
@@ -340,38 +335,49 @@ namespace Rivet {
         // Multi-dimensional cross-sections
         double norm_3D = 0, norm_3D_parton = 0;
         for (auto& h_it : _h_multi) {
-          if (h_it.first.find("_parton") != string::npos) for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, 2.1882987); }
+          if (h_it.first.find("_parton") != string::npos)  scale(h_it.second, 2.1882987);
           if (h_it.first.find("_norm") != string::npos) {
-            for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, sf); }
+            scale(h_it.second, sf);
             if (h_it.first.find("_3D") != string::npos) {
-              if (h_it.first.find("_parton") != string::npos) norm_3D_parton += integral_2D(h_it.second);
-              else norm_3D += integral_2D(h_it.second);
-              if (h_it.first.find("tt_y_1") != string::npos) { for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, 1 / 0.3); } }
-              if (h_it.first.find("tt_y_2") != string::npos) { for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, 1 / 0.6); } }
-              if (h_it.first.find("tt_y_3") != string::npos) { for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, 1 / 1.1); } }
+              if (h_it.first.find("_parton") != string::npos) norm_3D_parton += h_it.second->integral(false);
+              else norm_3D += h_it.second->integral(false);
+              if (h_it.first.find("tt_y_1") != string::npos) { scale(h_it.second, 1. / 0.3); }
+              if (h_it.first.find("tt_y_2") != string::npos) { scale(h_it.second, 1. / 0.6); }
+              if (h_it.first.find("tt_y_3") != string::npos) { scale(h_it.second, 1. / 1.1); }
             }
             else {
-             double norm_2D = integral_2D(h_it.second);
-             h_it.second.scale(safediv(1.0, norm_2D), this);
+              const double norm_2D = h_it.second->integral(false);
+              scale(h_it.second, safediv(1.0, norm_2D));
+              divByGroupWidth(h_it.second);
             }
           }
           else {
             if (h_it.first.find("_3D") != string::npos) {
-              if (h_it.first.find("tt_y_1") != string::npos) { for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, 1 / 0.3); } }
-              if (h_it.first.find("tt_y_2") != string::npos) { for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, 1 / 0.6); } }
-              if (h_it.first.find("tt_y_3") != string::npos) { for (Histo1DPtr& hist : h_it.second.histos()) { scale(hist, 1 / 1.1); } }
-              h_it.second.scale(sf, this);
+              if (h_it.first.find("tt_y_1") != string::npos) { scale(h_it.second, 1. / 0.3); }
+              if (h_it.first.find("tt_y_2") != string::npos) { scale(h_it.second, 1. / 0.6); }
+              if (h_it.first.find("tt_y_3") != string::npos) { scale(h_it.second, 1. / 1.1); }
+              scale(h_it.second, sf);
+              divByGroupWidth(h_it.second);
+            }
+            else {
+              scale(h_it.second, sf);
+              divByGroupWidth(h_it.second);
             }
-            else h_it.second.scale(sf, this);
           }
         }
-        _h_multi["tt_y_1_tt_m_t1_pt_3D_norm"].scale(safediv(1, norm_3D), this);
-        _h_multi["tt_y_2_tt_m_t1_pt_3D_norm"].scale(safediv(1, norm_3D), this);
-        _h_multi["tt_y_3_tt_m_t1_pt_3D_norm"].scale(safediv(1, norm_3D), this);
+        scale(_h_multi["tt_y_1_tt_m_t1_pt_3D_norm"], safediv(1, norm_3D));
+        divByGroupWidth(_h_multi["tt_y_1_tt_m_t1_pt_3D_norm"]);
+        scale(_h_multi["tt_y_2_tt_m_t1_pt_3D_norm"], safediv(1, norm_3D));
+        divByGroupWidth(_h_multi["tt_y_2_tt_m_t1_pt_3D_norm"]);
+        scale(_h_multi["tt_y_3_tt_m_t1_pt_3D_norm"], safediv(1, norm_3D));
+        divByGroupWidth(_h_multi["tt_y_3_tt_m_t1_pt_3D_norm"]);
         if (_mode) {
-          _h_multi["tt_y_1_tt_m_t1_pt_3D_parton_norm"].scale(safediv(1, norm_3D_parton), this);
-          _h_multi["tt_y_2_tt_m_t1_pt_3D_parton_norm"].scale(safediv(1, norm_3D_parton), this);
-          _h_multi["tt_y_3_tt_m_t1_pt_3D_parton_norm"].scale(safediv(1, norm_3D_parton), this);
+          scale(_h_multi["tt_y_1_tt_m_t1_pt_3D_parton_norm"], safediv(1, norm_3D_parton));
+          divByGroupWidth(_h_multi["tt_y_1_tt_m_t1_pt_3D_parton_norm"]);
+          scale(_h_multi["tt_y_2_tt_m_t1_pt_3D_parton_norm"], safediv(1, norm_3D_parton));
+          divByGroupWidth(_h_multi["tt_y_2_tt_m_t1_pt_3D_parton_norm"]);
+          scale(_h_multi["tt_y_3_tt_m_t1_pt_3D_parton_norm"], safediv(1, norm_3D_parton));
+          divByGroupWidth(_h_multi["tt_y_3_tt_m_t1_pt_3D_parton_norm"]);
         }
       }
 
@@ -415,7 +421,7 @@ namespace Rivet {
 
       size_t _mode;
       map<string, Histo1DPtr> _h;
-      map<string, BinnedHistogram> _h_multi;
+      map<string, Histo1DGroupPtr> _h_multi;
 
       //some functions for booking, filling and scaling the histograms
       void fill_hist(const std::string name, double value) {
@@ -429,13 +435,13 @@ namespace Rivet {
       }
 
       void fill_hist_2D(const std::string name, double value_external, double value_internal) {
-       _h_multi[name].fill(value_external, value_internal);
-       _h_multi[name + "_norm"].fill(value_external, value_internal);
+       _h_multi[name]->fill(value_external, value_internal);
+       _h_multi[name + "_norm"]->fill(value_external, value_internal);
       }
 
       void fill_hist_2D_parton(const std::string name, double value_external, double value_internal) {
-       _h_multi[name + "_parton"].fill(value_external, value_internal);
-       _h_multi[name + "_parton_norm"].fill(value_external, value_internal);
+       _h_multi[name + "_parton"]->fill(value_external, value_internal);
+       _h_multi[name + "_parton_norm"]->fill(value_external, value_internal);
       }
 
       void book_hist(const std::string name, unsigned int index) {
@@ -447,28 +453,25 @@ namespace Rivet {
         }
       }
 
-      void book_hist_2D(const std::string name, std::vector<double> external_bins, unsigned int index) {
-        for (unsigned int i = 0; i < external_bins.size() - 1; ++i) {
-          Histo1DPtr tmp;
-          _h_multi[name].add(external_bins[i], external_bins[i + 1], book(tmp, index + i, 1, 1));
-          _h_multi[name + "_norm"].add(external_bins[i], external_bins[i + 1], book(tmp, index + 72 + i, 1, 1));
-          if (_mode != 0) {
-            _h_multi[name + "_parton"].add(external_bins[i], external_bins[i + 1], book(tmp, index + 145 + i, 1, 1));
-            _h_multi[name + "_parton_norm"].add(external_bins[i], external_bins[i + 1], book(tmp, index + 217 + i, 1, 1));
+      void book_hist_2D(const std::string name, const vector<double>& external_bins, unsigned int index) {
+        book(_h_multi[name], external_bins);
+        book(_h_multi[name+"_norm"], external_bins);
+        if (_mode) {
+          book(_h_multi[name+"_parton"], external_bins);
+          book(_h_multi[name+"_parton_norm"], external_bins);
+        }
+        for (size_t i=0; i < _h_multi[name]->numBins(); ++i) {
+          book(_h_multi[name]->bin(i+1), index+i, 1, 1);
+          book(_h_multi[name+"_norm"]->bin(i+1), index+72+i, 1, 1);
+          if (_mode) {
+            book(_h_multi[name+"_parton"]->bin(i+1), index+145+i, 1, 1);
+            book(_h_multi[name+"_parton_norm"]->bin(i+1), index+217+i, 1, 1);
           }
         }
       }
 
-      double integral_2D(BinnedHistogram& hist_multi) {
-       double total_integral = 0;
-       for (Histo1DPtr& h : hist_multi.histos()) {
-         total_integral += h->integral(false);
-       }
-       return total_integral;
-     }
-
   };
 
 
-  DECLARE_RIVET_PLUGIN(ATLAS_2022_I2077575);
+  RIVET_DECLARE_PLUGIN(ATLAS_2022_I2077575);
 }
