@@ -15,7 +15,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -37,7 +37,7 @@ namespace Rivet {
 	  findChildren(child,nRes,ncount);
       }
     }
-    
+
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
@@ -48,7 +48,7 @@ namespace Rivet {
 	nCount[p.pid()] += 1;
 	++ntotal;
       }
-      
+
       // find the Lambdas and Sigmas
       const FinalState& ufs = apply<UnstableParticles>(event, "UFS");
       for(unsigned int ix=0;ix<ufs.particles().size();++ix) {
@@ -71,7 +71,6 @@ namespace Rivet {
       	for(unsigned int iy=ix+1;iy<ufs.particles().size();++iy) {
       	  const Particle& p2 = ufs.particles()[iy];
 	  if(abs(p2.pid())!=3122&&abs(p2.pid())!=3212) continue;
-	  if(p2.pid()*p1.pid()>0) continue;
 	  // check fs
 	  bool fs = true;
 	  for(const Particle & child : p2.children()) {
@@ -123,38 +122,28 @@ namespace Rivet {
 	  sigma = _nLS->val()*fact;
 	  error = _nLS->err()*fact;
 	}
-	Scatter2D temphisto(refData(ix, 1, 1));
-	Scatter2DPtr  mult;
+	Estimate1DPtr  mult;
         book(mult, ix, 1, 1);
-	for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	  const double x  = temphisto.point(b).x();
-	  pair<double,double> ex = temphisto.point(b).xErrs();
-	  pair<double,double> ex2 = ex;
-	  if(ex2.first ==0.) ex2. first=0.0001;
-	  if(ex2.second==0.) ex2.second=0.0001;
-	  if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	    mult->addPoint(x, sigma, ex, make_pair(error,error));
-	  }
-	  else {
-	    mult->addPoint(x, 0., ex, make_pair(0.,.0));
+	for (auto& b : mult->bins()) {
+	  if (inRange(sqrtS()/GeV, b.xMin(), b.xMax())) {
+	    b.set(sigma, error);
 	  }
 	}
       }
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
+    /// @{
     CounterPtr _nLL,_nSS,_nLS;
-    //@}
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(BABAR_2007_I760730);
 
 
