@@ -5,7 +5,7 @@
 namespace Rivet {
 
 
-  /// @brief B -> pi, rho , omega form factors
+  /// @brief Add a short analysis description here
   class BELLE_2013_I1238273 : public Analysis {
   public:
 
@@ -14,7 +14,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -33,7 +33,7 @@ namespace Rivet {
 
     // Calculate the Q2 using mother and daugher meson
     double q2(const Particle& B, int mesonID) {
-      FourMomentum q = B.mom() - filter_select(B.children(), Cuts::pid==mesonID)[0];
+      FourMomentum q = B.mom() - select(B.children(), Cuts::pid==mesonID)[0];
       return q*q;
     }
 
@@ -88,26 +88,25 @@ namespace Rivet {
 
     }
 
-    //@}
+    /// @}
 
 
   private:
 
 
     /// @name Histograms
-    //@{
+    /// @{
     Histo1DPtr _h_q2_B0bar_pi    ;
     Histo1DPtr _h_q2_B0bar_rho   ;
     Histo1DPtr _h_q2_Bminus_pi   ;
     Histo1DPtr _h_q2_Bminus_rho  ;
     Histo1DPtr _h_q2_Bminus_omega;
-    //@}
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(BELLE_2013_I1238273);
 
 
