@@ -2,7 +2,7 @@
 #include "Rivet/Analysis.hh"
 #include "Rivet/Projections/FinalState.hh"
 #include "Rivet/Projections/FastJets.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
 #include "Rivet/Projections/IdentifiedFinalState.hh"
 #include "Rivet/Projections/VetoedFinalState.hh"
@@ -14,9 +14,8 @@ namespace Rivet {
   public:
 
     /// Constructor
-    CMS_2016_I1491950()
-      : Analysis("CMS_2016_I1491950")
-    {    }
+    RIVET_DEFAULT_ANALYSIS_CTOR(CMS_2016_I1491950);
+
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -28,8 +27,8 @@ namespace Rivet {
 
     // Projection for dressed electrons and muons
     Cut leptonCuts = Cuts::abseta < 2.5 and Cuts::pt > 30.*GeV;
-    SpecialDressedLeptons dressedleptons(prompt_fs, leptonCuts);
-    declare(dressedleptons, "DressedLeptons");
+    SpecialLeptonFinder dressedleptons(prompt_fs, leptonCuts);
+    declare(dressedleptons, "LeptonFinder");
 
     // Neutrinos
     IdentifiedFinalState neutrinos(prompt_fs);
@@ -40,7 +39,7 @@ namespace Rivet {
     VetoedFinalState fsForJets(fs);
     fsForJets.addVetoOnThisFinalState(dressedleptons);
     fsForJets.addVetoOnThisFinalState(neutrinos);
-    declare(FastJets(fsForJets, FastJets::ANTIKT, 0.4, JetAlg::Muons::DECAY, JetAlg::Invisibles::DECAY), "Jets");
+    declare(FastJets(fsForJets, JetAlg::ANTIKT, 0.4, JetMuons::DECAY, JetInvisibles::DECAY), "Jets");
 
     //book hists
     book(_hist_thadpt, "d01-x02-y01");
@@ -107,8 +106,8 @@ namespace Rivet {
     void analyze(const Event& event) {
 
       // leptons
-      const SpecialDressedLeptons& dressedleptons_proj = applyProjection<SpecialDressedLeptons>(event, "DressedLeptons");
-      std::vector<DressedLepton> dressedLeptons = dressedleptons_proj.dressedLeptons();
+      const SpecialLeptonFinder& dressedleptons_proj = apply<SpecialLeptonFinder>(event, "LeptonFinder");
+      DressedLeptons dressedLeptons = dressedleptons_proj.dressedLeptons();
       if(dressedLeptons.size() != 1) return;
 
       // neutrinos
@@ -273,34 +272,34 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize()
     {
-      scale(_hist_thadpt, crossSection()/sumOfWeights());
-      scale(_hist_thady, crossSection()/sumOfWeights());
-      scale(_hist_tleppt, crossSection()/sumOfWeights());
-      scale(_hist_tlepy, crossSection()/sumOfWeights());
-      scale(_hist_ttpt, crossSection()/sumOfWeights());
-      scale(_hist_tty, crossSection()/sumOfWeights());
-      scale(_hist_ttm, crossSection()/sumOfWeights());
-      scale(_hist_njet, crossSection()/sumOfWeights());
-      scale(_hist_njets_thadpt_1, crossSection()/sumOfWeights());
-      scale(_hist_njets_thadpt_2, crossSection()/sumOfWeights());
-      scale(_hist_njets_thadpt_3, crossSection()/sumOfWeights());
-      scale(_hist_njets_thadpt_4, crossSection()/sumOfWeights());
-      scale(_hist_njets_ttpt_1, crossSection()/sumOfWeights());
-      scale(_hist_njets_ttpt_2, crossSection()/sumOfWeights());
-      scale(_hist_njets_ttpt_3, crossSection()/sumOfWeights());
-      scale(_hist_njets_ttpt_4, crossSection()/sumOfWeights());
-      scale(_hist_thady_thadpt_1, crossSection()/sumOfWeights()/0.5);
-      scale(_hist_thady_thadpt_2, crossSection()/sumOfWeights()/0.5);
-      scale(_hist_thady_thadpt_3, crossSection()/sumOfWeights()/0.5);
-      scale(_hist_thady_thadpt_4, crossSection()/sumOfWeights()/1.0);
-      scale(_hist_ttm_tty_1, crossSection()/sumOfWeights()/150.);
-      scale(_hist_ttm_tty_2, crossSection()/sumOfWeights()/175.);
-      scale(_hist_ttm_tty_3, crossSection()/sumOfWeights()/225.);
-      scale(_hist_ttm_tty_4, crossSection()/sumOfWeights()/1150.);
-      scale(_hist_ttpt_ttm_1, crossSection()/sumOfWeights()/35.);
-      scale(_hist_ttpt_ttm_2, crossSection()/sumOfWeights()/45.);
-      scale(_hist_ttpt_ttm_3, crossSection()/sumOfWeights()/60.);
-      scale(_hist_ttpt_ttm_4, crossSection()/sumOfWeights()/360.);
+      scale(_hist_thadpt, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_thady, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_tleppt, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_tlepy, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_ttpt, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_tty, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_ttm, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njet, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_thadpt_1, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_thadpt_2, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_thadpt_3, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_thadpt_4, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_ttpt_1, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_ttpt_2, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_ttpt_3, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_njets_ttpt_4, crossSection()/picobarn/sumOfWeights());
+      scale(_hist_thady_thadpt_1, crossSection()/picobarn/sumOfWeights()/0.5);
+      scale(_hist_thady_thadpt_2, crossSection()/picobarn/sumOfWeights()/0.5);
+      scale(_hist_thady_thadpt_3, crossSection()/picobarn/sumOfWeights()/0.5);
+      scale(_hist_thady_thadpt_4, crossSection()/picobarn/sumOfWeights()/1.0);
+      scale(_hist_ttm_tty_1, crossSection()/picobarn/sumOfWeights()/150.);
+      scale(_hist_ttm_tty_2, crossSection()/picobarn/sumOfWeights()/175.);
+      scale(_hist_ttm_tty_3, crossSection()/picobarn/sumOfWeights()/225.);
+      scale(_hist_ttm_tty_4, crossSection()/picobarn/sumOfWeights()/1150.);
+      scale(_hist_ttpt_ttm_1, crossSection()/picobarn/sumOfWeights()/35.);
+      scale(_hist_ttpt_ttm_2, crossSection()/picobarn/sumOfWeights()/45.);
+      scale(_hist_ttpt_ttm_3, crossSection()/picobarn/sumOfWeights()/60.);
+      scale(_hist_ttpt_ttm_4, crossSection()/picobarn/sumOfWeights()/360.);
 
       scale(_histnorm_thadpt, 1./_histnorm_thadpt->sumW(false));
       scale(_histnorm_thady, 1./_histnorm_thady->sumW(false));
@@ -342,36 +341,36 @@ namespace Rivet {
     /// @brief Special dressed lepton finder
     ///
     /// Find dressed leptons by clustering all leptons and photons
-    class SpecialDressedLeptons : public FinalState {
+    class SpecialLeptonFinder : public FinalState {
     public:
 
       /// The default constructor. May specify cuts
-      SpecialDressedLeptons(const FinalState& fs, const Cut& cut)
+      SpecialLeptonFinder(const FinalState& fs, const Cut& cut)
         : FinalState(cut)
       {
-        setName("SpecialDressedLeptons");
+        setName("SpecialLeptonFinder");
         IdentifiedFinalState ifs(fs);
         ifs.acceptIdPair(PID::PHOTON);
         ifs.acceptIdPair(PID::ELECTRON);
         ifs.acceptIdPair(PID::MUON);
         declare(ifs, "IFS");
-        declare(FastJets(ifs, FastJets::ANTIKT, 0.1), "LeptonJets");
+        declare(FastJets(ifs, JetAlg::ANTIKT, 0.1), "LeptonJets");
       }
 
       /// Clone on the heap.
       virtual unique_ptr<Projection> clone() const {
-        return unique_ptr<Projection>(new SpecialDressedLeptons(*this));
+        return unique_ptr<Projection>(new SpecialLeptonFinder(*this));
       }
 
       /// Import to avoid warnings about overload-hiding
       using Projection::operator =;
 
       /// Retrieve the dressed leptons
-      const vector<DressedLepton>& dressedLeptons() const { return _clusteredLeptons; }
+      const DressedLeptons& dressedLeptons() const { return _clusteredLeptons; }
 
     private:
       /// Container which stores the clustered lepton objects
-      vector<DressedLepton> _clusteredLeptons;
+      DressedLeptons _clusteredLeptons;
 
     public:
       void project(const Event& e) {
@@ -379,9 +378,9 @@ namespace Rivet {
         _theParticles.clear();
         _clusteredLeptons.clear();
 
-        vector<DressedLepton> allClusteredLeptons;
+        DressedLeptons allClusteredLeptons;
 
-        const Jets jets = applyProjection<FastJets>(e, "LeptonJets").jetsByPt(5.*GeV);
+        const Jets jets = apply<FastJets>(e, "LeptonJets").jetsByPt(Cuts::pT > 5.*GeV);
         for (const Jet& jet : jets) {
           Particle lepCand;
           for (const Particle& cand : jet.particles()) {
@@ -406,8 +405,8 @@ namespace Rivet {
         for (const DressedLepton& lepton : allClusteredLeptons) {
           if (accept(lepton)) {
             _clusteredLeptons.push_back(lepton);
-            _theParticles.push_back(lepton.constituentLepton());
-            _theParticles += lepton.constituentPhotons();
+            _theParticles.push_back(lepton.bareLepton());
+            _theParticles += lepton.photons();
           }
         }
       }
@@ -485,7 +484,6 @@ namespace Rivet {
 
 
 
- // The hook for the plugin system
  RIVET_DECLARE_PLUGIN(CMS_2016_I1491950);
 
 }
