@@ -10,6 +10,7 @@ namespace Rivet {
 
   namespace H1_2007_I746380_PROJECTIONS {
 
+
     /// Projection to find the largest gaps and the masses of the two
     /// systems separated by the gap. Based on the HZTools gap-finding
     /// method (hzhadgap.F). Note that gaps are found in the HCM frame.
@@ -24,10 +25,10 @@ namespace Rivet {
       RapidityGap() {
         setName("RapidityGap");
         declare(DISKinematics(), "DISKIN");
-        declare(DISFinalState(DISFinalState::BoostFrame::HCM), "DISFS");
+        declare(DISFinalState(DISFrame::HCM), "DISFS");
       }
 
-      DEFAULT_RIVET_PROJ_CLONE(RapidityGap);
+      RIVET_DEFAULT_PROJ_CLONE(RapidityGap);
 
       /// Import to avoid warnings about overload-hiding
       using Projection::operator =;
@@ -206,9 +207,11 @@ namespace Rivet {
           }
         }
 
-        // Find t: Currently can only handle gap on proton side.
-        // @TODO: Expand to also handle gap on photon side
         // Boost p from LAB to HCM frame to find t.
+        ///
+        /// @note Currently can only handle gap on proton side.
+        ///
+        /// @todo Expand to also handle gap on photon side
         const FourMomentum proton = hcmboost.transform(diskin.beamHadron().momentum());
         FourMomentum pPom         = proton - _momY_HCM;
         _t                        = pPom * pPom;
@@ -240,7 +243,7 @@ namespace Rivet {
       // Return the boost to XCM frame.
       const LorentzTransform& boost() const { return _boost; }
 
-      DEFAULT_RIVET_PROJ_CLONE(BoostedXSystem);
+      RIVET_DEFAULT_PROJ_CLONE(BoostedXSystem);
 
       /// Import to avoid warnings about overload-hiding
       using Projection::operator =;
@@ -305,16 +308,16 @@ namespace Rivet {
     RIVET_DEFAULT_ANALYSIS_CTOR(H1_2007_I746380);
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     // Book projections and histograms
     void init() {
 
       declare(DISKinematics(), "Kinematics");
-      const DISFinalState& disfs = declare(DISFinalState(DISFinalState::BoostFrame::HCM), "DISFS");
+      const DISFinalState& disfs = declare(DISFinalState(DISFrame::HCM), "DISFS");
       const BoostedXSystem& disfsXcm = declare( BoostedXSystem(disfs), "BoostedXFS");
       declare(FastJets(disfsXcm, fastjet::JetAlgorithm::kt_algorithm, fastjet::RecombinationScheme::pt_scheme, 1.0,
-                       JetAlg::Muons::ALL, JetAlg::Invisibles::NONE, nullptr), "DISFSJets");
+                       JetMuons::ALL, JetInvisibles::NONE, nullptr), "DISFSJets");
       declare(RapidityGap(), "RapidityGap");
 
       // Book histograms from REF data
@@ -513,13 +516,13 @@ namespace Rivet {
 
     }
 
-    //@}
+    /// @}
 
 
   private:
 
     /// @name Histograms
-    //@{
+    /// @{
     // Book histograms from REF data
     Histo1DPtr _h_DIS_dsigdzPom    ;
     Histo1DPtr _h_DIS_dsigdlogXpom ;
@@ -537,7 +540,7 @@ namespace Rivet {
     Histo1DPtr _h_PHO_dsigdAvgEta  ;
     Histo1DPtr _h_PHO_dsigdDeltaEta;
     Histo1DPtr _h_PHO_dsigdMjets   ;
-    //@}
+    /// @}
 
     bool isDIS;
     int  nVeto0, nVeto1, nVeto2, nVeto3, nVeto4, nVeto5;
