@@ -9,6 +9,7 @@
 
 namespace Rivet {
 
+
   namespace H1_2015_I1343110_PROJECTIONS {
 
     /// Projection to find the largest gaps and the masses of the two
@@ -25,10 +26,10 @@ namespace Rivet {
       RapidityGap() {
         setName("RapidityGap");
         declare(DISKinematics(), "DISKIN");
-        declare(DISFinalState(DISFinalState::BoostFrame::HCM), "DISFS");
+        declare(DISFinalState(DISFrame::HCM), "DISFS");
       }
 
-      DEFAULT_RIVET_PROJ_CLONE(RapidityGap);
+      RIVET_DEFAULT_PROJ_CLONE(RapidityGap);
 
       /// Import to avoid warnings about overload-hiding
       using Projection::operator =;
@@ -207,9 +208,11 @@ namespace Rivet {
           }
         }
 
-        // Find t: Currently can only handle gap on proton side.
-        // @TODO: Expand to also handle gap on photon side
         // Boost p from LAB to HCM frame to find t.
+        ///
+        /// @note Currently can only handle gap on proton side.
+        ///
+        /// @todo Expand to also handle gap on photon side
         const FourMomentum proton = hcmboost.transform(diskin.beamHadron().momentum());
         FourMomentum pPom         = proton - _momY_HCM;
         _t                        = pPom * pPom;
@@ -241,7 +244,7 @@ namespace Rivet {
       // Return the boost to XCM frame.
       const LorentzTransform& boost() const { return _boost; }
 
-      DEFAULT_RIVET_PROJ_CLONE(BoostedXSystem);
+      RIVET_DEFAULT_PROJ_CLONE(BoostedXSystem);
 
       /// Import to avoid warnings about overload-hiding
       using Projection::operator =;
@@ -288,6 +291,7 @@ namespace Rivet {
 
   }
 
+
   /// @brief H1 diffractive dijets
   ///
   /// Diffractive dijets H1 with 920 GeV p and 27.5 GeV e
@@ -304,16 +308,16 @@ namespace Rivet {
     typedef H1_2015_I1343110_PROJECTIONS::BoostedXSystem BoostedXSystem;
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     // Book projections and histograms
     void init() {
 
       declare(DISKinematics(), "Kinematics");
-      const DISFinalState& disfs = declare(DISFinalState(DISFinalState::BoostFrame::HCM), "DISFS");
+      const DISFinalState& disfs = declare(DISFinalState(DISFrame::HCM), "DISFS");
       const BoostedXSystem& disfsXcm = declare( BoostedXSystem(disfs), "BoostedXFS");
       declare(FastJets(disfsXcm, fastjet::JetAlgorithm::kt_algorithm, fastjet::RecombinationScheme::pt_scheme, 1.0,
-                       JetAlg::Muons::ALL, JetAlg::Invisibles::NONE, nullptr), "DISFSJets");
+                       JetMuons::ALL, JetInvisibles::NONE, nullptr), "DISFSJets");
       declare(DISDiffHadron(), "Hadron");
       declare(RapidityGap(), "RapidityGap");
 
@@ -478,7 +482,7 @@ namespace Rivet {
 
       // Now fill histograms
       if (isPHO){
-        _h_PHO_sig_sqrts     ->fill(sqrtS()/GeV);
+        _h_PHO_sig_sqrts     ->fill(319);
         _h_PHO_dsigdz        ->fill(zPomJets);
         _h_PHO_dsigdxPom     ->fill(xPom);
         _h_PHO_dsigdy        ->fill(y);
@@ -488,7 +492,7 @@ namespace Rivet {
         _h_PHO_dsigdDeltaEta ->fill(deltaEtaJets);
         _h_PHO_dsigdAvgEta   ->fill(avgEtaJets);
       } else {
-        _h_DIS_sig_sqrts     ->fill(sqrtS()/GeV);
+        _h_DIS_sig_sqrts     ->fill(319);
         _h_DIS_dsigdz        ->fill(zPomJets);
         _h_DIS_dsigdxPom     ->fill(xPom);
         _h_DIS_dsigdy        ->fill(y);
@@ -553,17 +557,17 @@ namespace Rivet {
 
     }
 
-    //@}
+    /// @}
 
 
   private:
 
     /// @name Histograms
-    //@{
+    /// @{
     // Book histograms from REF data
-    Histo1DPtr _h_PHO_sig_sqrts;
-    Histo1DPtr _h_DIS_sig_sqrts;
-    Scatter2DPtr _h_PHODIS_sqrts;
+    BinnedHistoPtr<int> _h_PHO_sig_sqrts;
+    BinnedHistoPtr<int> _h_DIS_sig_sqrts;
+    BinnedEstimatePtr<int> _h_PHODIS_sqrts;
 
     Histo1DPtr _h_DIS_dsigdz;
     Histo1DPtr _h_DIS_dsigdxPom;
@@ -583,11 +587,11 @@ namespace Rivet {
     Histo1DPtr _h_PHO_dsigdDeltaEta;
     Histo1DPtr _h_PHO_dsigdAvgEta;
 
-    Scatter2DPtr _h_PHODIS_deltaEta;
-    Scatter2DPtr _h_PHODIS_y;
-    Scatter2DPtr _h_PHODIS_z;
-    Scatter2DPtr _h_PHODIS_Etj1;
-    //@}
+    Estimate1DPtr _h_PHODIS_deltaEta;
+    Estimate1DPtr _h_PHODIS_y;
+    Estimate1DPtr _h_PHODIS_z;
+    Estimate1DPtr _h_PHODIS_Etj1;
+    /// @}
 
     bool isPHO;
     int  nVeto1, nVeto2, nVeto3, nVeto4, nVeto5, nVeto6;
