@@ -34,8 +34,8 @@ namespace Rivet {
       declare(thrust, "Thrust"    );
       declare(Hemispheres(thrust), "Hemispheres");
       declare(ParisiTensor(fs), "Parisi");
-      declare(FastJets(cfs, FastJets::DURHAM, 0.7), "DurhamJets");
-      declare(FastJets(cfs, FastJets::JADE  , 0.7), "JadeJets"  );
+      declare(FastJets(cfs, JetAlg::DURHAM, 0.7), "DurhamJets");
+      declare(FastJets(cfs, JetAlg::JADE  , 0.7), "JadeJets"  );
       // histograms
       book(_histThrust    ,  1, 1, 1);
       book(_histMajor     ,  2, 1, 1);
@@ -61,7 +61,8 @@ namespace Rivet {
       const FinalState& cfs = apply<FinalState>(event, "CFS");
       if(cfs.particles().size()<5) vetoEvent;
       // charged particle mult
-      _histMult->fill(cfs.particles().size());
+      const string multi_edge = std::to_string(cfs.particles().size()) + ".0";
+      _histMult->fill(multi_edge);
       // Sphericity related
       const Sphericity& sphericity = apply<Sphericity>(event, "Sphericity");
       _histSphericity->fill(sphericity.sphericity());
@@ -122,7 +123,7 @@ namespace Rivet {
       scale(_histMJetHeavy , 1./sumOfWeights());
       scale(_histMJetLight , 1./sumOfWeights());
       // percentage and bin width
-      scale(_histMult, 100.*2./sumOfWeights());
+      scale(_histMult, 100./sumOfWeights());
     }
 
     ///@}
@@ -135,7 +136,8 @@ namespace Rivet {
     Histo1DPtr _histH3,_histH4;
     Histo1DPtr _histSphericity, _histAplanarity;
     Histo1DPtr _histC, _histD;
-    Histo1DPtr _histMJetHeavy, _histMJetLight, _histMult;
+    Histo1DPtr _histMJetHeavy, _histMJetLight;
+    BinnedHistoPtr<string> _histMult;
     ///@}
 
 
