@@ -5,7 +5,7 @@
 namespace Rivet {
 
 
-  /// @brief Add a short analysis description here
+  /// @brief e+e- > 3pi+3pi-
   class DM1_1981_I166353 : public Analysis {
   public:
 
@@ -14,13 +14,13 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       // Initialise and register projections
       declare(FinalState(), "FS");
-      book(_num3pip3pim, "TMP/num3pip3pim");
+      book(_num3pip3pim, "TMP/num3pip3pim",refData(1,1,1));
     }
 
 
@@ -33,43 +33,27 @@ namespace Rivet {
 	++ntotal;
       }
       if(ntotal!=6) vetoEvent;
-      _num3pip3pim->fill();
+      _num3pip3pim->fill(sqrtS()/GeV);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      double sigma = _num3pip3pim->val()*fact;
-      double error = _num3pip3pim->err()*fact;
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr mult;
+      scale(_num3pip3pim,crossSection()/ sumOfWeights() /nanobarn);
+      Estimate1DPtr mult;
       book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      barchart(_num3pip3pim,mult);
     }
-    //@}
+    /// @}
 
     /// @name Histograms
-    //@{
-    CounterPtr _num3pip3pim;
-    //@}
+    /// @{
+    Histo1DPtr _num3pip3pim;
+    /// @}
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(DM1_1981_I166353);
 
 
