@@ -1,4 +1,3 @@
-from __future__ import print_function
 import rivet, yoda
 import os, glob, logging, re
 from math import sqrt
@@ -30,11 +29,14 @@ def _parse_args(args):
     filelist : list[str]
         Raw names of the files, i.e. the first part of each string in args.
     filenames : list[str]
-        Names of the files. If Name=value is passed as a plot option after a file name, this will become the filename. Otherwise, it will use the same value as in filelist.
+        Names of the files. If Name=value is passed as a plot option after a file name, this will become the filename.
+        Otherwise, it will use the same value as in filelist.
     plotoptions : dict[str, dict[str, str]]
         Dictionary of plot options.
-        The key will be the file name (i.e., same value as in filenames) and the value will be a dict of strings with plot options.
-        One of the keys will also be PLOT (if it was passed in as an argument to args, which contains all plot options that will be applied to the entire figure.
+        The key will be the file name, unless Name=label is passed as a plot option after a file name,
+        in which case it will be label. The dictionary value with be a dict of strings with plot options.
+        One of the keys will also be PLOT (if it was passed in as an argument to args, which contains
+        all plot options that will be applied to the entire figure.
 
     Examples
     --------
@@ -51,17 +53,16 @@ def _parse_args(args):
     ----
     Some matplotlib line styles contain ':', which would not work with current code. TODO: change delimiter?
     """
-    # TODO: remove filenames since they exist as keys in plotoptions?
     filelist = []
-    filenames = []
     plotoptions = {}
     for a in args:
         asplit = a.split(':')
         path = asplit[0]
-        if path != "PLOT":
+        if path != "PLOT" and not re.fullmatch(r"REF(\d+)?$", path):
             filelist.append(path)
+            path = path.split('/')[-1]
             while path in plotoptions:
-                patj = '_' + path
+                path = '_' + path
         plotoptions[path] = {}
         has_title = False
         has_name = ""
@@ -79,8 +80,8 @@ def _parse_args(args):
             plotoptions[has_name] = plotoptions.pop(path)
         else:
             has_name = path
-        if path != "PLOT" and not has_title:
-            plotoptions[has_name if has_name != "" else path]['Title'] = _sanitise_string(os.path.basename( os.path.splitext(path)[0] ))
+        if path != "PLOT" and not re.fullmatch(r"REF(\d+)?$", path) and not has_title:
+            plotoptions[has_name]['Title'] = _sanitise_string(os.path.basename( os.path.splitext(path)[0] ))
     return filelist, plotoptions
 
 
@@ -88,7 +89,7 @@ def _get_histos(filelist, plotoptions, path_patterns = [], path_unpatterns = [],
     """Loop over all input files. Only use the first occurrence of any REF-histogram
     and the first occurrence in each MC file for every MC-histogram."""
 
-    hpaths = []; anas = [];
+    hpaths = []; anas = []
     hasVariations = False
     refhistos, mchistos = {}, {}
     for infile, inname in zip(filelist, plotoptions.keys()):
@@ -111,11 +112,10 @@ def _get_histos(filelist, plotoptions, path_patterns = [], path_unpatterns = [],
             if aop.istmp() or aop.israw():
                 continue
 
-            hasVariations != bool(aop.varid())
+            hasVariations |= bool(aop.varid())
 
             # Convert non-scatter objects to scatter
-            if "Scatter" not in ao.type():
-                ao = ao.mkScatter()
+            ao = yoda.plotting.utils.mkPlotFriendlyScatter(ao)
 
             ## Add it to the ref or mc paths, if this path isn't already known
             basepath = rivet.stripOptions(aop.basepath(keepref=False))
@@ -132,7 +132,7 @@ def _get_histos(filelist, plotoptions, path_patterns = [], path_unpatterns = [],
                         anas.append(ana)
 
     if rivetrefs:
-        # Scape Rivet ref-data files for matching ref-data AOs
+        # Scrape Rivet ref-data files for matching ref-data AOs
         rivet_data_dirs = rivet.getAnalysisRefPaths()
         dirlist = list(set([ item for a in anas
                                   for d in rivet_data_dirs
@@ -154,33 +154,41 @@ def _get_histos(filelist, plotoptions, path_patterns = [], path_unpatterns = [],
     return refhistos, mchistos, hpaths
 
 
-def _add_ref_hist(output, refhisto, mainlabel, ratiolabel):
-    reflabel = 'Data'
+def _add_ref_hist(output, refhisto, reftitle, ratiolabel):
     refhisto.setAnnotation('IsRef', True)
-    output['histograms'][reflabel] = {'nominal': refhisto}
-    output['histograms'][reflabel]['IsRef'] = True
-    output['histograms'][reflabel]['LineColor'] = 'black'
-    # set label for reference data in legend
-    output['histograms'][reflabel]['Title'] = mainlabel
+    # assemble array of REF/REF2/... for every reference curve tag on
+    # the command line, sort them based on tailing digits, then loop
+    for ref_key in sorted(list(set([ tag for tag in output.keys()
+                       if re.fullmatch(r"REF(\d+)?$", tag) ] + ['REF'])),
+                       key=lambda k : int(k[3:] if len(k) > 3 else 0)):
+        reflabel = reftitle + (ref_key[3:] if len(ref_key) > 3 else '')
+        errpat = output.get(ref_key, {}).get('ErrorPattern', '')
+        # check if a band was explicitly requested
+        needsBand = len([ val for key, val in output.get(ref_key, {}).items()
+                                           if 'ErrorBand' in key and val ])
+        # add new reference curve
+        output['histograms'][reflabel] = {
+            'nominal' : yoda.plotting.utils.mkPlotFriendlyScatter(refhisto, errorPattern=errpat)
+        }
+        output['histograms'][reflabel]['IsRef'] = True
+        output['histograms'][reflabel]['LineColor'] = 'black'
+        # set label for reference data in legend
+        output['histograms'][reflabel]['Title'] = reftitle
+        # set additional reference-data options
+        output['histograms'][reflabel].update(output.get(ref_key, {}))
+        if needsBand:
+            bandao = yoda.plotting.utils.mkPlotFriendlyScatter(refhisto, errorPattern=errpat)
+            output['histograms'][reflabel]['BandUncertainty'] = bandao
+
     # decide if ratio panel is shown or not
     output['plot features']['RatioPlot'] = ratiolabel != None
     # set label on y-axis of the ratio panel
     output['plot features']['RatioPlotYLabel'] = ratiolabel
 
-def get_nominal_key(listOfHistoKeys):
-    """try to find the key corresponding to the nominal histogram,
-       which seems to differ between different YODA files
-    """
-    name = '0'
-    if 'nominal' in listOfHistoKeys: name='nominal'
-    elif 'yoda' in listOfHistoKeys:  name='yoda'
-    elif '0' in listOfHistoKeys:  name='0'
-    return name
-
 
 def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptions,
-                 style, rc_params, mc_errs, nRatioTicks, skipWeights, removeOptions, deviation,
-                 canvasText, refLabel = None, ratioPlotLabel = None, showRatio = None, verbose = False,):
+                 style, rc_params, mc_errs, nRatioTicks, showWeights, removeOptions, deviation,
+                 canvasText, refLabel=None, ratioPlotLabel = None, showRatio = None, verbose = False,):
 
     """Create output dictionary for the plot_id.
 
@@ -220,9 +228,9 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
     outputdict = {}
     plot_configs = plot2yaml.get_plot_configs(plot_id, plotdirs=plotdirs, config_files=config_files)
     outputdict['plot features'] = plot_configs
+    if deviation:
+        outputdict['plot features']['RatioPlotMode'] = 'deviation'
     rpmode = plot_configs.get('RatioPlotMode', 'mcdata')
-    deviation |= plot_configs.get('Deviation', False)
-    outputdict['plot features']['Deviation'] = deviation or rpmode == 'deviation'
 
     # only write extra info to the .dat file if specified by user
     if nRatioTicks !=1: outputdict['plot features'].update({"nRatioTicks": nRatioTicks})
@@ -232,9 +240,14 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
     outputdict['style'] = style
     outputdict['stylepath'] = '../'
     outputdict['histograms'] = {}
+    outputdict['pat_warn'] = {}
+    for key, val in plotoptions.items():
+        if re.fullmatch(r"REF(\d+)?$", key):
+            outputdict[key] = val
 
     componentNames = ['BandComponentPDF', 'BandComponentEnv']
 
+    # Check if there's reference data
     if plot_id in refhistos and rpmode != 'datamc':
         # Adding it first ensures it goes in the denominator
         rplabel = None
@@ -242,12 +255,12 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
         if hasRatio:
             rplabel = ratioPlotLabel if ratioPlotLabel != None else \
                       refhistos[plot_id].annotation('RatioPlotYLabel', 'MC/Data')
-        reftitle = refhistos[plot_id].annotation('Title', 'Data')
-        mainlabel = refLabel if refLabel != None else \
-                    reftitle if reftitle != None else 'Data'
-        _add_ref_hist(outputdict, refhistos[plot_id], mainlabel, rplabel)
+        reftitle = refLabel if refLabel != None else \
+                   refhistos[plot_id].annotation('Title', 'Data')
+        reflabel = reftitle if reftitle != None else 'Data'
+        _add_ref_hist(outputdict, refhistos[plot_id], reflabel, rplabel)
 
-    # Now add MC curve
+    # Now add MC curves
     lhapdfCheck = True
     for filename, mchistos_in_file in mchistos.items():
         for plot_id_with_anaopt in sorted(mchistos_in_file):
@@ -266,10 +279,8 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
             thisFilePlotOptions['Title'] = newtitle
             outputdict['histograms'][filename+label].update(thisFilePlotOptions)
 
-            makePDFBand  = thisFilePlotOptions['BandComponentPDF'] \
-                           if 'BandComponentPDF' in thisFilePlotOptions else ''
-            makeEnvelope = thisFilePlotOptions['BandComponentEnv'] \
-                           if 'BandComponentEnv' in thisFilePlotOptions else ''
+            makePDFBand  = thisFilePlotOptions.get('BandComponentPDF', '')
+            makeEnvelope = thisFilePlotOptions.get('BandComponentEnv', '')
 
             # check if lhapdf is available
             if makePDFBand and lhapdfCheck:
@@ -282,7 +293,7 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
                             f" failing `import {e.name}`")
                     exit(1)
 
-            nominalVariationKey = get_nominal_key(mchistos_in_file[plot_id_with_anaopt].keys())
+            nominalVariationKey = thisFilePlotOptions.get('DefaultWeight', '0')
             if nominalVariationKey == None:
                 raise NameError("Could not find nominal variation weight!")
 
@@ -300,15 +311,14 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
                 # pass the plotoptions dict to the function?
                 outputdict['histograms'][filename+label]['ErrorBars'] = mc_errs
 
-                thisObj = histogram.mkScatter()
+                thisObj = yoda.plotting.utils.mkPlotFriendlyScatter(histogram)
 
                 # no support for 3D scatters and bands
                 if thisObj.type() == "Scatter3D":
                     makeEnvelope = makePDFBand = ''
 
                 # central values of current object
-                central_values = [ p.x() if 'Scatter1D' in thisObj.type() else
-                  p.y() if 'Scatter2D' in thisObj.type() else p.z() for p in thisObj.points() ]
+                central_values = thisObj.vals(thisObj.dim()-1)
 
                 if isNominal:
                     nominalScatter = thisObj
@@ -340,8 +350,8 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
                             Enverrors[i][0] = list(map(min, zip(Enverrors[i][0], central_values)))
                             Enverrors[i][1] = list(map(max, zip(Enverrors[i][1], central_values)))
 
-                # don't plot multiweights if already plotting a band
-                if not skipWeights and not isNominal and not makeEnvelope and not makePDFBand:
+                # Don't plot multiweights if already plotting a band
+                if showWeights and not isNominal and not makeEnvelope and not makePDFBand:
                     # Check if the user supplied regex-based weightname filtering
                     var_filter = thisFilePlotOptions.get('Variations', '')
                     if var_filter:
@@ -351,17 +361,23 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
 
             for pat in pdf_matches:
                 if not len(pdf_matches[pat]):
-                    print (f"WARNING: PDF band prescription '{pat}' did not match any variation weights!")
+                    if verbose:
+                        print (f"WARNING: PDF band prescription '{pat}' did not match any variation weights!")
+                    elif not pat in outputdict['pat_warn'].setdefault('PDF band', {}).setdefault(filename, []):
+                        outputdict['pat_warn']['PDF band'][filename].append(pat)
                 elif verbose:
                     print ("PDF prescription \"%s\" matches:" % pat)
                     print (pdf_matches[pat])
             for pat in env_matches:
                 if not len(env_matches[pat]):
-                    print (f"WARNING: Envelope prescription '{pat}' did not match any variation weights!")
+                    if verbose:
+                        print (f"WARNING: Envelope prescription '{pat}' did not match any variation weights!")
+                    elif not pat in outputdict['pat_warn'].setdefault('Envelope', {}).setdefault(filename, []):
+                        outputdict['pat_warn']['Envelope'][filename].append(pat)
                 elif verbose:
                     print ("Envelope prescription \"%s\" matches:" % pat)
                     print (env_matches[pat])
-                del pdf_matches, env_matches
+            del pdf_matches, env_matches
 
             PDFerrors = [ ]
             for pdf_set, pdf_vars in zip(PDFsets, PDFvars):
@@ -387,8 +403,8 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
 
                 BandScatter = nominalScatter.clone()
                 # iterate over bins
-                for ibin, y in enumerate(nominalScatter.yVals() if 'Scatter2D' in nominalScatter.type() else nominalScatter.xVals()):
-                    totErrDn, totErrUp = BandScatter.point(ibin).yErrs() if 'Scatter2D' in BandScatter.type() else BandScatter.point(0).xErrs()
+                for ibin, y in enumerate(nominalScatter.vals(nominalScatter.dim()-1)):
+                    totErrDn, totErrUp = BandScatter.point(ibin).errs(BandScatter.dim()-1)
                     totErrDn = totErrDn*totErrDn
                     totErrUp = totErrUp*totErrUp
 
@@ -405,7 +421,7 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
                         totErrUp += absEnvUp*absEnvUp
 
                     # Scatter object with total Band uncertainty
-                    BandScatter.point(ibin).setYErrs(sqrt(totErrDn), sqrt(totErrUp))
+                    BandScatter.point(ibin).setErrs(BandScatter.dim()-1, sqrt(totErrDn), sqrt(totErrUp))
                 outputdict['histograms'][filename+label]['BandUncertainty'] = BandScatter
 
     # Check if there's reference data
@@ -416,17 +432,16 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
         if hasRatio:
             rplabel = ratioPlotLabel if ratioPlotLabel != None else \
                       refhistos[plot_id].annotation('RatioPlotYLabel', 'Data/MC')
-        reftitle = refhistos[plot_id].annotation('Title', 'Data')
-        mainlabel = refLabel if refLabel != None else \
-                    reftitle if reftitle != None else 'Data'
-        _add_ref_hist(outputdict, refhistos[plot_id], mainlabel, rplabel)
-
+        reftitle = refLabel if refLabel != None else \
+                   refhistos[plot_id].annotation('Title', 'Data')
+        reflabel = reftitle if reftitle != None else 'Data'
+        _add_ref_hist(outputdict, refhistos[plot_id], reflabel, rplabel)
 
     # Remove all sections of the output_dict that do not contain any information.
     # A list of keys is first created. Otherwise, it will raise an error since the size of the dict changes.
     dict_keys = list(outputdict.keys())
     for key in dict_keys:
-        if not outputdict[key]:
+        if not outputdict[key] or re.fullmatch(r"REF(\d+)?$", key):
             del outputdict[key]
     return outputdict
 
@@ -436,7 +451,7 @@ def assemble_plotting_data(args, path_pwd=True, rivetrefs=True,
                            plotinfodirs=[], style='default', config_files=[],
                            hier_output=False, outdir='.', mc_errs=True,
                            rivetplotpaths=True, analysispaths=[], verbose=False,
-                           nRatioTicks=1, skipWeights=False,
+                           nRatioTicks=1, showWeights=False,
                            removeOptions = False, deviation=False,
                            canvasText=None, refLabel=None, ratioPlotLabel=None,
                            showRatio=None):
@@ -540,17 +555,28 @@ def assemble_plotting_data(args, path_pwd=True, rivetrefs=True,
     hasVariations = hpaths.pop()
 
     # Write each file
-    plot_info_dicts = {}
+    plot_info_dicts, pattern_warnings = {}, {}
     for plot_id in hpaths:
         outputdict = _make_output(
             plot_id, plotdirs, config_files,
             mchistos, refhistos,
             plotoptions, stylename, rc_params_dict, mc_errs,
-            nRatioTicks, skipWeights, removeOptions, deviation,
+            nRatioTicks, showWeights, removeOptions, deviation,
             canvasText, refLabel, ratioPlotLabel, showRatio, verbose
         )
-        if 'histograms' in outputdict: # protection against Counters
-            plot_info_dicts[plot_id] = outputdict
+        for presc, warnings in outputdict.setdefault('pat_warn', {}).items():
+            for filename, pats in warnings.items():
+                for pat in pats:
+                    if not pat in pattern_warnings.setdefault(presc, {}).setdefault(filename, []):
+                        pattern_warnings[presc][filename].append(pat)
+        del outputdict['pat_warn']
+        plot_info_dicts[plot_id] = outputdict
+    if not verbose:
+        for presc, warnings in pattern_warnings.items():
+            for filename, pats in warnings.items():
+                for pat in pats:
+                    print (f"WARNING: {presc} prescription '{pat}' did not match "
+                           + f"any variation weights in file '{filename}'!")
 
     return plot_info_dicts, hasVariations
 
