@@ -11,8 +11,8 @@ namespace Rivet {
       return;
     }
     LorentzTransform hcmboost; //< Null boost = LAB frame by default
-    if (_boosttype == BoostFrame::HCM) hcmboost = diskin.boostHCM();
-    else if (_boosttype == BoostFrame::BREIT) hcmboost = diskin.boostBreit();
+    if (_boosttype == DISFrame::HCM) hcmboost = diskin.boostHCM();
+    else if (_boosttype == DISFrame::BREIT) hcmboost = diskin.boostBreit();
 
     const DISLepton& dislep = diskin.apply<DISLepton>(e, "Lepton");
     if ( diskin.failed() ) {
@@ -31,7 +31,7 @@ namespace Rivet {
 
     for (const Particle& p : fs.particles()) { ///< Ensure that we skip the DIS lepton
       Particle temp = p;
-      if (_boosttype != BoostFrame::LAB) temp.setMomentum(hcmboost.transform(temp.momentum()));
+      if (_boosttype != DISFrame::LAB) temp.setMomentum(hcmboost.transform(temp.momentum()));
       if (p.genParticle() != dislepGP)  _theParticles.push_back(temp);
     }
   }
