@@ -23,7 +23,7 @@ function _clean() {
 
 function _setup() {
     _clean
-    cp ${RIVET_TESTS_SRC}/testApi.hepmc file2.hepmc
+    cp ${RIVET_TESTS_SRC}/testAPI.hepmc file2.hepmc
     mkfifo fifo.hepmc
 }
 
@@ -49,17 +49,17 @@ rivet --show-analysis SLD_1999_S37439 > log || exit $?
 
 
 echo
-rivet -a D0_2008_S7554427 ${RIVET_TESTS_SRC}/testApi.hepmc file2.hepmc > log || exit $?
+rivet -a D0_2008_S7554427 ${RIVET_TESTS_SRC}/testAPI.hepmc file2.hepmc > log || exit $?
 grep -q "20 events" log
 _check
 
-echo
-cat ${RIVET_TESTS_SRC}/testApi.hepmc | rivet -a D0_2008_S7554427 > log || exit $?
-grep -q "10 events" log
-_check
+#echo "OI-2"
+#cat ${RIVET_TESTS_SRC}/testAPI.hepmc | rivet -a D0_2008_S7554427 > log || exit $?
+#grep -q "10 events" log
+#_check
 
-echo
-cat ${RIVET_TESTS_SRC}/testApi.hepmc > fifo.hepmc &
+echo "OI-3"
+cat ${RIVET_TESTS_SRC}/testAPI.hepmc > fifo.hepmc &
 rivet -a D0_2008_S7554427 fifo.hepmc > log || exit $?
 grep -q "10 events" log
 _check
